@@ -182,11 +182,15 @@ AudioOpenAL::~AudioOpenAL()
 		if(context_id)
 			alcDestroyContext(context_id);
 		#endif
+
+		alcCloseDevice(dev);
 		
 		alutExit();
 
 		fprintf(stderr, "done.\n");
 	}
+
+	delete soundQueue;
 }
 
 //----------------------------------------------------------
@@ -213,7 +217,6 @@ static void warning(const char *, ...)
 bool AudioOpenAL::createContext()
 {
 #ifdef _WIN32
-	ALCdevice *dev;
  	dev=alcOpenDevice((unsigned char*)"DirectSound",NULL);
 	context_id=(void*)alcCreateContext(dev,NULL);
 	alcMakeContextCurrent((ALCcontext*)context_id);
@@ -221,7 +224,6 @@ bool AudioOpenAL::createContext()
 #ifdef OLD_OPENAL
 	context_id = alcCreateContext(NULL);
 #else
-	ALCdevice *dev;
 	dev = alcOpenDevice( NULL );
 	context_id = alcCreateContext(dev, NULL);
 	alcMakeContextCurrent(context_id);
