@@ -7,9 +7,9 @@
  */
 #include "EnemyAircraft.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 
 #include "Config.h"
 
