@@ -7,9 +7,9 @@
  */
 #include "HeroAircraft.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cmath>
 
 #include "compatibility.h"
 #include <GL/gl.h>
@@ -663,12 +663,12 @@ void HeroAircraft::checkForPowerUps(PowerUps *powerUps)
 			}
 			game->explosions->addExplo(Explosions::PowerBurst, pwrUp->pos);
 			delUp = pwrUp;
-			pwrUp = powerUps->getNext();
+			pwrUp = pwrUp->next;
 			powerUps->remove(delUp);
 		}
 		else
 		{
-			pwrUp = powerUps->getNext();
+			pwrUp = pwrUp->next;
 		}
 	}
 }
@@ -723,6 +723,7 @@ void HeroAircraft::update()
 					if(gunActive[i])
 					{
 						if(gunPause[i] < flash)
+						{
 							if(gunSwap)
 							{
 								gunFlash0[i] = (flash-pause)/flash;
@@ -733,6 +734,7 @@ void HeroAircraft::update()
 								gunFlash0[i] = 0.0;
 								gunFlash1[i] = (flash-pause)/flash;
 							}
+						}
 					}
 					else
 					{
