@@ -7,8 +7,8 @@
  */
 #include "ScreenItemAdd.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
 
 #include "define.h"
 #include "Global.h"
@@ -33,6 +33,8 @@ ScreenItemAdd::ScreenItemAdd()
 
 ScreenItemAdd::~ScreenItemAdd()
 {
+	clear();
+	delete root;
 }
 
 //----------------------------------------------------------	
